==> nextcloud-23.0.12p1.tgz: nextcloud/apps/updatenotification/l10n/sr.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Верзија {version} је доступна. Сазнајте како да ажурирате.",
    "Channel updated" : "Канал ажуриран",
    "Update notifications" : "Обавештења о ажурирању",
    "The update server could not be reached since %d days to check for new updates." : "Сервер за ажурирања није доступан пошто је прошло %d дана од последње провере ажурирања.",
    "Please check the Nextcloud and server log files for errors." : "Проверите логове од сервера и од Некстклауда за грешке.",
    "Update to %1$s is available." : "Доступно је ажурирање на %1$s. ",
    "Update for %1$s to version %2$s is available." : "Доступно је ажурирање апликације %1$s на верзију %2$s.",
    "Update for {app} to version %s is available." : "Доступно је ажурирање апликације {app} на верзију %s.",
    "Update notification" : "Обавештење о ажурирању",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Приказује обавештавања о ажурирањима за Некстклауд и омогућава јединствену пријаву за програм ажурирања.",
    "Update" : "Ажурирај",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Верзија коју тренутно користите се више не одржава. Постарајте се да ажурирате инсталацију на неку подржану верзију што је пре могуће.",
    "View in store" : "Погледај у продавници",
    "Open updater" : "Отвори програм за ажурирање",
    "Download now" : "Скини сада",
    "What's new?" : "Шта је ново?",
    "The update check is not yet finished. Please refresh the page." : "Провера за новим верзијама још није готова. Освежите страну.",
    "Your version is up to date." : "Ваша верзија је ажурна.",
    "A non-default update server is in use to be checked for updates:" : "Неподразумевани сервер за ажурирање је коришћен да провери нове верзије:",
    "Update channel:" : "Канал за ажурирање:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Увек можете да надоградите на новију верзију. Али не можете се вратити на стабилнију верзију.",
    "Notify members of the following groups about available updates:" : "Обавести чланове следећих група о доступности нових верзија:",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Уз означени канал за ажурирање нема смисла да имате обавештења о новим верзијама.",
    "The selected update channel does not support updates of the server." : "Означени канал за ажурирање не подржава обавештења о новим верзијама.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Доступна је нова верзија: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Проверено {lastCheckedDate}",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Проверите да у config.php фајлу немате <samp>appstoreenabled</samp> постављено на „false“.",
    "View changelog" : "Погледајте дневник измена",
    "Enterprise" : "Предузетничка",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "За предузећа. Пружа најновији ниво закрпа, али неће одмах да ажурира аутоматски на следећу главну верзију. То ажурирање ће се десити када Nextcloud GmbH обави додатне провере и тестирања на великим и критичним системима. Овај канал је доступан само муштеријама и пружа  Nextcloud Enterprise пакет.",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Најскорашњија стабилна верзија. Погодна за редовну употребу и увек ће бити на најновијој главној верзији.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Пред-издање и служи само за тестирање нових могућности, не за свакодневни рад."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/updatenotification/l10n/sr.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Верзија {version} је доступна. Сазнајте како да ажурирате.",
    "Channel updated" : "Канал ажуриран",
    "Update notifications" : "Обавештења о ажурирању",
    "The update server could not be reached since %d days to check for new updates." : "Сервер за ажурирања није доступан пошто је прошло %d дана од последње провере ажурирања.",
    "Please check the Nextcloud and server log files for errors." : "Проверите логове од сервера и од Некстклауда за грешке.",
    "Update to %1$s is available." : "Доступно је ажурирање на %1$s. ",
    "Update for {app} to version %s is available." : "Доступно је ажурирање апликације {app} на верзију %s.",
    "Update notification" : "Обавештење о ажурирању",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Приказује обавештавања о ажурирањима за Некстклауд и омогућава јединствену пријаву за програм ажурирања.",
    "Update" : "Ажурирај",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Верзија коју тренутно користите се више не одржава. Постарајте се да ажурирате инсталацију на неку подржану верзију што је пре могуће.",
    "View in store" : "Погледај у продавници",
    "Open updater" : "Отвори програм за ажурирање",
    "Download now" : "Скини сада",
    "What's new?" : "Шта је ново?",
    "The update check is not yet finished. Please refresh the page." : "Провера за новим верзијама још није готова. Освежите страну.",
    "Your version is up to date." : "Ваша верзија је ажурна.",
    "A non-default update server is in use to be checked for updates:" : "Неподразумевани сервер за ажурирање је коришћен да провери нове верзије:",
    "Update channel:" : "Канал за ажурирање:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Увек можете да надоградите на новију верзију. Али не можете се вратити на стабилнију верзију.",
    "Notify members of the following groups about available updates:" : "Обавести чланове следећих група о доступности нових верзија:",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Уз означени канал за ажурирање нема смисла да имате обавештења о новим верзијама.",
    "The selected update channel does not support updates of the server." : "Означени канал за ажурирање не подржава обавештења о новим верзијама.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Доступна је нова верзија: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Проверено {lastCheckedDate}",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Проверите да у config.php фајлу немате <samp>appstoreenabled</samp> постављено на „false“.",
    "View changelog" : "Погледајте дневник измена",
    "Enterprise" : "Предузетничка",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "За предузећа. Пружа најновији ниво закрпа, али неће одмах да ажурира аутоматски на следећу главну верзију. То ажурирање ће се десити када Nextcloud GmbH обави додатне провере и тестирања на великим и критичним системима. Овај канал је доступан само муштеријама и пружа  Nextcloud Enterprise пакет.",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Најскорашњија стабилна верзија. Погодна за редовну употребу и увек ће бити на најновијој главној верзији.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Пред-издање и служи само за тестирање нових могућности, не за свакодневни рад.",
    "Update for %1$s to version %2$s is available." : "Доступно је ажурирање апликације %1$s на верзију %2$s."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
